# Generated by roxygen2: do not edit by hand

S3method(print,fit_lin)
S3method(print,fit_nlin2)
export(AUDPC)
export(AUDPC_2_points)
export(AUDPS)
export(expo_fun)
export(fit_lin)
export(fit_multi)
export(fit_nlin)
export(fit_nlin2)
export(gompi_fun)
export(logi_fun)
export(mono_fun)
export(plot_fit)
export(sim_exponential)
export(sim_gompertz)
export(sim_logistic)
export(sim_monomolecular)
importFrom(magrittr,"%>%")
importFrom(minpack.lm,nls.lm.control)
