#' epifitter: Analysis and simulation of plant disease progress curves
#'
#' Internal package documentation used to generate the package namespace.
#'
#' @keywords internal
#' @importFrom magrittr %>%
#' @importFrom minpack.lm nls.lm.control
"_PACKAGE"
