% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sim_logistic.R
\name{sim_logistic}
\alias{sim_logistic}
\title{Simulate a logistic disease progress curve}
\usage{
sim_logistic(N = 10, dt = 1, y0 = 0.01, r, K = 1, n, alpha = 0.2)
}
\arguments{
\item{N}{Total epidemic duration.}

\item{dt}{Time interval between assessments.}

\item{y0}{Initial disease intensity.}

\item{r}{Apparent infection rate.}

\item{K}{Maximum disease intensity.}

\item{n}{Number of replicated curves.}

\item{alpha}{Noise level applied to replicated observations.}
}
\value{
A data frame with simulated disease progress values and replicated
  noisy observations.
}
\description{
Simulate disease progress data under the logistic epidemic model, with
optional replicated observations.
}
\examples{
sim_logistic(N = 30, dt = 5, y0 = 0.01, r = 0.05, K = 1, n = 4)

}
