% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AUDPC_2_points.R
\name{AUDPC_2_points}
\alias{AUDPC_2_points}
\title{Estimate AUDPC from two observations}
\usage{
AUDPC_2_points(time, y0, yT)
}
\arguments{
\item{time}{Time elapsed between the two assessments.}

\item{y0}{Initial disease intensity as a proportion.}

\item{yT}{Final disease intensity as a proportion.}
}
\value{
A numeric scalar with the estimated AUDPC.
}
\description{
Estimate the area under the disease progress curve from only the initial and
final observations under a logistic epidemic assumption.
}
\examples{
epi <- sim_logistic(N = 30, y0 = 0.01, dt = 5, r = 0.3, alpha = 0.5, n = 1)
AUDPC_2_points(time = epi$time[7], y0 = epi$y[1], yT = epi$y[7])

}
\references{
Jeger, M. J., and Viljanen-Rollinson, S. L. H. (2001). The use of the area
under the disease-progress curve (AUDPC) to assess quantitative disease
resistance in crop cultivars. \emph{Theoretical and Applied Genetics},
102, 32-40.
}
