% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/logi_fun.R
\name{logi_fun}
\alias{logi_fun}
\title{Logistic model differential equation}
\usage{
logi_fun(t, y, par)
}
\arguments{
\item{t}{Time.}

\item{y}{State variable.}

\item{par}{Model parameters.}
}
\value{
A list containing the rate of change.
}
\description{
Internal helper used by the simulation functions to solve the logistic
epidemic model with `deSolve::ode()`.
}
