% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_fit.R
\name{plot_fit}
\alias{plot_fit}
\title{Plot fitted epidemic models}
\usage{
plot_fit(
  object,
  point_size = 1.2,
  line_size = 1,
  models = c("Exponential", "Monomolecular", "Logistic", "Gompertz")
)
}
\arguments{
\item{object}{A fitted object returned by `fit_lin()`, `fit_nlin()`, or
`fit_nlin2()`.}

\item{point_size}{Point size for observed values.}

\item{line_size}{Line width for fitted curves.}

\item{models}{Character vector with the models to display.}
}
\value{
A `ggplot2` object.
}
\description{
Create a faceted `ggplot2` panel showing observed and fitted values for the
selected epidemic models.
}
\examples{
epi <- sim_logistic(N = 30, y0 = 0.01, dt = 5, r = 0.3, alpha = 0.2, n = 4)
fit <- fit_lin(time = epi$time, y = epi$random_y)
plot_fit(fit)

}
